@@ -20,6 +20,9 @@ def keygen(bit_length):
     return params, pk, sk
 
 def encrypt(params, pk, m):
+    if isinstance(m, np.matrix):
+        m = np.array(m)
+
     # scalar
     if isinstance(m, int):
         return _encrypt(params, pk, m)
@@ -41,6 +44,9 @@ def encrypt(params, pk, m):
         return None
 
 def decrypt(params, sk, c):
+    if isinstance(c, np.matrix):
+        c = np.array(c)
+
     # scalar
     if isinstance(c[0], int):
         return _decrypt(params, sk, c)
@@ -62,17 +68,22 @@ def decrypt(params, sk, c):
         return None
 
 def mult(params, c1, c2):
+    if isinstance(c1, np.matrix):
+        c1 = np.array(c1)
+    if isinstance(c2, np.matrix):
+        c2 = np.array(c2)
+
     # scalar x scalar
     if isinstance(c1[0], int) and isinstance(c2[0], int):
         return _mult(params, c1, c2)
     # scalar x vector
-    if isinstance(c1[0], int) and isinstance(c2[0][0], int):
+    elif isinstance(c1[0], int) and isinstance(c2[0][0], int):
         c = np.zeros(c2.shape, dtype=object)
         for i in range(c.shape[0]):
             c[i] = _mult(params, c1, c2[i])
         return c
     # scalar x matrix
-    if isinstance(c1[0], int) and isinstance(c2[0][0][0], int):
+    elif isinstance(c1[0], int) and isinstance(c2[0][0][0], int):
         c = np.zeros(c2.shape, dtype=object)
         for i in range(c.shape[0]):
             for j in range(c.shape[1]):
@@ -117,23 +128,25 @@ def dec(params, sk, c, delta):
     return decode(params, decrypt(params, sk, c), delta)
 
 def dec_add(params, sk, c, delta):
+    if isinstance(c, np.matrix):
+        c = np.array(c)
+
     # scalar
     if isinstance(c[0], int):
         return dec(params, sk, c, delta)
     # vector
     elif isinstance(c[0][0], int):
-        x = 0
-        for i in range(c.shape[0]):
-            x += dec(params, sk, c[i], delta)
-        return x
+        x = dec(params, sk, c, delta)
+        for i in range(1, x.shape[0]):
+            x[0] += x[i]
+        return x[0]
     # matrix
     elif isinstance(c[0][0][0], int):
-        x = np.zeros(c.shape[0], dtype=object)
-        for i in range(c.shape[1]):
-            x[i] = dec(params, sk, c[i][0], delta)
-            for j in range(1, c.shape[0]):
-                x[i] += dec(params, sk, c[i][j], delta)
-        return x
+        x = dec(params, sk, c, delta)
+        for i in range(x.shape[0]):
+            for j in range(1, x.shape[1]):
+                x[i][0] += x[i][j]
+        return x[:,0]
     else:
         print('error: decryption with addition')
         return None
